
![Test](https://github.com/eadwinCode/django-ninja-jwt/workflows/Test/badge.svg)
[![PyPI version](https://badge.fury.io/py/django-ninja-jwt.svg)](https://badge.fury.io/py/django-ninja-jwt)
[![PyPI version](https://img.shields.io/pypi/v/djangorestframework-simplejwt.svg)](https://pypi.python.org/pypi/django-ninja-jwt)
[![PyPI version](https://img.shields.io/pypi/pyversions/django-ninja-jwt.svg)](https://pypi.python.org/pypi/django-ninja-jwt)
[![PyPI version](https://img.shields.io/pypi/djversions/django-ninja-jwt.svg)](https://pypi.python.org/pypi/django-ninja-jwt)

A JSON Web Token authentication plugin for the [Django Ninja REST Framework](https://github.com/vitalik/django-ninja).

------------------------------------------------------------------------

Ninja JWT provides a JSON Web Token authentication backend for the
Django REST Framework. It aims to cover the most common use cases of
JWTs by offering a conservative set of default features. It also aims to
be easily extensible in case a desired feature is not present.

Acknowledgments
------

This project borrows code from the [SIMPLE JWT](https://github.com/jazzband/djangorestframework-simplejwt) to implement Json Web Token for Django Ninja REST Framework.
However, I have included SIMPLE JWT license to the `license` folder.

